<?php

namespace AppBundle\Controller\Ajax;

use AppBundle\Entity\User;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Class AjaxUserController
 * @package AppBundle\Controller\Ajax
 */
class AjaxUserController extends Controller
{

    /**
     * Render Ajax page.
     *
     * @Route("ajax/user-delete", options={"expose"=true}, name="app_ajax_remove_user")
     * @Method({"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxDeleteAction(Request $request){

        //If is not ajax
        if(!$request->isXmlHttpRequest()){

            return new Response('Bad Request', 400);

        }

        $this->denyAccessUnlessGranted(User::ROLE_SYSTEM_ADMIN);

        $data = json_decode($request->getContent(), true);
        $request->request->replace($data);

        $userId = $request->request->get('userId');

        /** @var UserManager $userManager */
        $userManager = $this->get('fos_user.user_manager');

        $user = $userManager->findUserBy(array('id' => $userId));

        if(!$user){

            $data = array('status' => 'failed', 'msg' => 'User does not exist.');

            return new JsonResponse($data);

        }

        if($user->getUsername() == 'admin'){

            $data = array('status' => 'failed', 'msg' => 'User Administrator cannot be deleted.');

            return new JsonResponse($data);

        }

        try{

            $userName = $user->getUsername();

            $userManager->deleteUser($user);

            $data = array('status' => 'success', 'msg' => 'User "'. $userName .'" was successfully deleted.');

        }catch (\Exception $e){

            $data = array('status' => 'failed', 'msg' => 'User cannot be deleted.');

        }

        return new JsonResponse($data);

    }

}