<?php

namespace AppBundle\EventListener;

use Symfony\Component\DependencyInjection\Container;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpKernel\Event\GetResponseForExceptionEvent;

/**
 * Class AjaxAuthenticationListener
 * @package AppBundle\EventListener
 */
class AjaxAuthenticationListener
{

    /**
     * @var Container
     */
    protected $container;

    /**
     * AjaxAuthenticationListener constructor.
     * @param Container $container
     */
    public function __construct(Container $container){

        $this->container = $container;

    }


    /**
     * Handles security related exceptions.
     *
     * @param GetResponseForExceptionEvent $event An GetResponseForExceptionEvent instance
     */
    public function onCoreException(GetResponseForExceptionEvent $event)
    {
        $exception = $event->getException();
        $request = $event->getRequest();

        if ($request->isXmlHttpRequest()){

            $token = $this->container->get('security.token_storage')->getToken();

            if (null !== $token && !is_object($user = $token->getUser())){

                // e.g. anonymous authentication
                $event->setResponse(new Response('', 401));

            }elseif ($exception instanceof AuthenticationException || $exception instanceof AccessDeniedException){

                $event->setResponse(new Response('', 403));

            }

        }

    }

}