<?php
namespace AppBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Validator\ValidatorBuilder;

class DeviceFwRule extends AbstractType
{
    /**
     * @param FormBuilderInterface $builder
     * @param array                $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder

            ->add('enabled', CheckboxType::class, array(
                'label_render' => true,
                'label' => '<b style="padding-left: 5px;">Enable</b>',
                'widget_checkbox_label' => 'widget',
                //'label_format' => '%name%',
                //'attr' => array('class' => 'startdate span1 js-switch'),
                //'attr' => array('class' => 'startdate span1 '),
                'horizontal_input_wrapper_class' => "col-lg-3 col-lg-offset-3",
                //'horizontal_label_class' => 'col-md-2',
                //'horizontal_input_wrapper_class' => 'test'
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper' => false,
                //'attr' => array('checked' => 'checked'),
                'required' => false,
                //'empty_data' => true,
                //'data' => true,
            ))
            /*
            ->add('enabled', ChoiceType::class, array(
                'label_render' => true,
                'label' => '<b style="padding-left: 5px;">Enable</b>',
                'widget_checkbox_label' => 'widget',
                'horizontal_input_wrapper_class' => "col-lg-3 col-lg-offset-3",
                //'choice_value' => function (MyOptionEntity $entity = null) {
                //    return $entity ? $entity->getId() : '';
                //},
                'expanded' => true, //checkbox
                'multiple' => true, //checkbox
                'required' => false,
                //'empty_data' => true,
            ))*/
            ->add('protocol', ChoiceType::class, array(
                'choices' => array(
                    'TCP' => 'tcp',
                    'UDP' => 'udp',
                    'ICMP' => 'icmp',
                ),

                //'attr' => array('class' => 'startdate span1', 'style'=>"font-size: 12px;"),
                //'horizontal_label_class' => 'col-md-2',
                //'label_attr' => array('class'=>'col-sm-2 '),
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper_class' => "col-lg-2",
            ))
            ->add('sourceIps', TextType::class, array(
                'required' => false,
                'label' => 'Source IPs',
                'render_optional_text' => false,
                //'attr' => array('class' => 'startdate span1'),
                //'horizontal_label_class' => 'col-md-1',
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper_class' => "col-lg-3",
               ))
            ->add('destinationIps', TextType::class, array(
                'required' => false,
                'label' => 'Destination IPs',
                'render_optional_text' => false,
                //'attr' => array('class' => 'startdate span1'),
                //'horizontal_label_class' => 'col-md-1',
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper_class' => "col-lg-3",
            ))
            ->add('ports', TextType::class, array(
                'required' => false,
                'label' => 'Ports',
                'render_optional_text' => false,
                //'attr' => array('class' => 'startdate span1'),
                //'horizontal_label_class' => 'col-md-1',
                //'widget_form_group_attr' => array('class'=>'form-horizontal '),
                //'horizontal_input_wrapper_class' => "col-lg-3",
            ));
    }


    /**
     * @param $data
     * @param $context
     * @return bool
     */
    public function validate($data, $context){


        $builder = new ValidatorBuilder();
        $validator = $builder->getValidator();

        $protocol = $data->getProtocol();
        $destinationIps = $data->getDestinationIps();
        $sourceIps = $data->getSourceIps();
        $ports = $data->getPorts();

        $destinationIpsViolations = $validator->validate($destinationIps, [new Assert\NotBlank()]);
        $sourceIpsViolations = $validator->validate($sourceIps, [new Assert\NotBlank()]);
        $portsViolations = $validator->validate($ports, [new Assert\NotBlank()]);
        
        if ($protocol != 'icmp' && count($destinationIpsViolations) > 0 && count($sourceIpsViolations) > 0 && count($portsViolations) > 0) {

            $context->buildViolation('At least one of the value Source Ip, Destination Ip or Port must be filled.')->addViolation();

        }

    }

        /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver){

        $resolver->setDefaults(array(
            'data_class' => \AppBundle\Entity\DeviceFwRule::class,
            'constraints' => array(new Assert\Callback(array($this, 'validate'))),
        ));

    }


    /**
     * @return string
     */
    public function getName()
    {
        return 'device_fw_rule';
    }

}