<?php

namespace AppBundle\Form;

use AppBundle\Entity\DeviceLan;
use AppBundle\Validator\Constraints\ValidDeviceLan;
use AppBundle\Validator\Constraints\ValidDeviceLanPrivate;
use AppBundle\Validator\Constraints\ValidDeviceLanPublic;
use AppBundle\Validator\Constraints\ValidDeviceLan1to1Nat;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Validator\ValidatorBuilder;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\Ip;
use Symfony\Component\Form\FormView;
use Symfony\Component\Form\FormInterface;

class DeviceLans extends AbstractType
{

    /**
     * @var string
     */
    private $deviceId;

    /**
     * @var \AppBundle\Api\Device
     */
    private $apiDevice;

    /**
     * @var string
     */
    private $virtualIpBase;

    /**
     * @var string
     */
    private $virtualMaskBase;

    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options){

        $this->deviceId = $options['deviceId'];
        $this->apiDevice = $options['apiDevice'];
        $this->virtualIpBase = $options['virtualIpBase'];
        $this->virtualMaskBase = $options['virtualMaskBase'];

        $builder->add('mode', ChoiceType::class, array(
            'label' => 'Mode:',
            'attr' => array('autocomplete' => 'off'),
            'choices' => array('Ignored' => 0, 'Local Only' => 1, 'VPN Public' => 2, 'VPN 1:1 NAT' => 3 )
            )
        );

        $builder->add('ifaceIp', TextType::class, array('label' => 'IP Address:', 'required' => false));
        $builder->add('netmask', TextType::class, array('label' => 'Netmask:', 'required' => false));
        $builder->add('dhcpEnabled', CheckboxType::class, array('label' => 'DHCP Enabled:', 'required' => false));
        $builder->add('dhcpFrom', TextType::class, array('label' => 'DHCP From:', 'required' => false));
        $builder->add('dhcpTo', TextType::class, array('label' => 'DHCP To:', 'required' => false));
        $builder->add('virtualIp', TextType::class, array('label' => 'Virtual Network IP Address:' , 'required' => false));
        $builder->add('virtualNetmask', TextType::class, array('label' => 'Virtual Netmask:' , 'required' => false));

    }

    /**
     * @param $data
     * @param $context
     * @return bool
     */
    public function validateIpConflict($data, $context){

        /* 
        XXX - Lukas K. added for some reason correction of virtual IP into this 
              function. We need this correction to be done, but don't know how
              to move it elsewhere. So for now it is left here, although it does
              not make any sense. */
                
        $data->setVirtualIp($this->virtualIpBase . '.' . $data->getVirtualIp());
        $data->setVirtualNetmask($this->virtualMaskBase . '.' . $data->getVirtualNetmask());
                
        /*
        XXX - This code is now obsolete and should be reworked, because LANs can no longer be 
              checked separately, but must be checked for all interfaces at once. There is now 
              a temporary simplistic check of conflict in 'setLans' web method, but it needs
              to be improved.
        
        $builder = new ValidatorBuilder();
        $validator = $builder->getValidator();

        $mode = $data->getMode();
        $interface = $data->getName();
        $ifaceIp = $data->getIfaceIp();
        $mask = $data->getNetmask();
        $isDhcpEnabled = (($data->getDhcpEnabled() === true) ? '1' : '0');
        $dhcpFrom = $data->getDhcpFrom();
        $dhcpTo = $data->getDhcpTo();
        $data->setVirtualIp($this->virtualIpBase . '.' . $data->getVirtualIp());

        if($mode == '0'){

            //Ignored, no need to validate
            return true;

        }elseif($mode == '1' || $mode == '2' || $mode == '3'){


            //Private or Public
            $ipViolations = $validator->validate($ifaceIp, [new NotBlank(), new Ip()]);

            if (count($ipViolations) > 0) {

                $context->buildViolation($ipViolations[0]->getMessage())->atPath('ifaceIp')->addViolation();

            }

            $netMaskViolations = $validator->validate($mask, [new NotBlank(), new Ip()]);

            if (count($netMaskViolations) > 0) {

                $context->buildViolation($netMaskViolations[0]->getMessage())->atPath('netmask')->addViolation();

            }

            if($isDhcpEnabled){

                //DHCP check
                $dhcpFromViolations = $validator->validate($dhcpFrom, [new NotBlank(), new Ip()]);

                if (count($dhcpFromViolations) > 0) {

                    $context->buildViolation($dhcpFromViolations[0]->getMessage())->atPath('dhcpFrom')->addViolation();

                }

                $dhcpToViolations = $validator->validate($dhcpTo, [new NotBlank(), new Ip()]);

                if (count($dhcpToViolations) > 0) {

                    $context->buildViolation($dhcpToViolations[0]->getMessage())->atPath('dhcpTo')->addViolation();

                }

            }

            if (count($ipViolations) == 0 && count($netMaskViolations) == 0) {

                $properties = array('apiDevice' => $this->apiDevice, 'deviceId' => $this->deviceId, 'interface' => $interface,
                    'ifaceIp' => $ifaceIp, 'mask' => $mask, 'dhcpEnabled' => $isDhcpEnabled, 'dhcpFrom' => $dhcpFrom,
                    'dhcpTo' => $dhcpTo);

                if($mode == 1){

                    //Private
                    $violations = $validator->validate($ifaceIp, [ new ValidDeviceLanPrivate(array(
                        'properties' => $properties,
                    ))]);

                    if (count($violations) > 0) {

                        $context->buildViolation($violations[0]->getMessage())->atPath('ifaceIp')->addViolation();
                    }

                }elseif ($mode == 2){

                    //Public
                    $violations = $validator->validate($ifaceIp, [ new ValidDeviceLanPublic(array(
                        'properties' => $properties,
                    ))]);

                    if (count($violations) > 0) {

                        $context->buildViolation($violations[0]->getMessage())->atPath('ifaceIp')->addViolation();
                    }


                }elseif ($mode == 3){

                    $virtualIpViolations = $validator->validate($virtualIp, [new NotBlank(), new Ip()]);

                    if (count($virtualIpViolations) > 0) {

                        $context->buildViolation($virtualIpViolations[0]->getMessage())->atPath('virtualIp')->addViolation();

                    }

                    $virtualMaskViolations = $validator->validate($virtualMask, [new NotBlank(), new Ip()]);

                    if (count($virtualMaskViolations) > 0) {

                        $context->buildViolation($virtualMaskViolations[0]->getMessage())->atPath('virtualNetmask')->addViolation();

                    }

                    if (count($virtualIpViolations) == 0 && count($virtualMaskViolations) == 0) {

                        $properties['virtualIp'] = $virtualIp;
                        $properties['virtualMask'] = $virtualMask;

                        //Public
                        $violations = $validator->validate($ifaceIp, [ new ValidDeviceLan1to1Nat(array(
                            'properties' => $properties,
                        ))]);

                        if (count($violations) > 0) {

                            $context->buildViolation($violations[0]->getMessage())->atPath('virtualIp')->addViolation();

                        }

                    }
                }
            }
        }
        */
    }

    /**
     * @param FormView $view
     * @param FormInterface $form
     * @param array $options
     */
    public function buildView(FormView $view, FormInterface $form, array $options){

        $view->vars = array_replace($view->vars, array(
            'deviceId' => $options['deviceId'],
            'apiDevice' => $options['apiDevice'],
        ));

    }

    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver){

        $resolver->setDefaults(array(
            'data_class' => DeviceLan::class,
            'constraints' => array(new Assert\Callback(array($this, 'validateIpConflict'))),
        ));

        $resolver->setRequired('deviceId');
        $resolver->setRequired('apiDevice');
        $resolver->setRequired('virtualIpBase');
        $resolver->setRequired('virtualMaskBase');

    }

}
